@@ -12,14 +12,14 @@ use warnings;
 use version;
 use Carp;
 use English qw/ -no_match_vars /;
-use Path::Class;
+use Path::Tiny;
 use File::chdir;
 use Group::Git::Repo;
 use Types::Standard qw/Str Int Bool HashRef/;
 use Type::Utils;
 use Module::Pluggable require => 1, search_path => ['Group::Git::Cmd', 'Group::Git::Taggers'];
 
-our $VERSION = version->new('0.5.3');
+our $VERSION = version->new('0.5.4');
 our $AUTOLOAD;
 
 has conf => (
@@ -72,7 +72,7 @@ for my $plugin (@plugins) {
 sub _repos {
     my ($self) = @_;
     my %repos;
-    my @files = dir('.')->children;
+    my @files = path('.')->children;
 
     while ( my $file = shift @files ) {
         next unless -d $file;
@@ -144,7 +144,7 @@ Group::Git - Base module for group of git repository operations.
 
 =head1 VERSION
 
-This documentation refers to Group::Git version 0.5.3.
+This documentation refers to Group::Git version 0.5.4.
 
 =head1 SYNOPSIS
 
