@@ -13,9 +13,9 @@ use version;
 use Carp;
 use English qw/ -no_match_vars /;
 use Net::GitHub;
-use Path::Class;
+use Path::Tiny;
 
-our $VERSION = version->new('0.5.3');
+our $VERSION = version->new('0.5.4');
 
 extends 'Group::Git';
 
@@ -48,7 +48,7 @@ sub _repos {
             $url =~ s{git://github.com/([^/]+)}{git\@github.com:$1};
 
             $repos{ $repo->{name} } = Group::Git::Repo->new(
-                name => dir($repo->{name}),
+                name => path($repo->{name}),
                 git  => $url,
             );
 
@@ -90,7 +90,7 @@ Group::Git::Github - Adds reading all repositories you have access to on github.
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Github version 0.5.3.
+This documentation refers to Group::Git::Github version 0.5.4.
 
 
 =head1 SYNOPSIS
