@@ -12,10 +12,10 @@ use warnings;
 use version;
 use Carp;
 use English qw/ -no_match_vars /;
-use Path::Class;
+use Path::Tiny;
 use File::chdir;
 
-our $VERSION = version->new('0.5.3');
+our $VERSION = version->new('0.5.4');
 
 extends 'Group::Git';
 
@@ -56,7 +56,7 @@ sub _repos {
 
                 for my $name ( split /\s+/, $data->{$group}{$sub_group}{$type} ) {
                     $repos{$name} = Group::Git::Repo->new(
-                        name => dir($name),
+                        name => path($name),
                         git  => "$base$name.git",
                     );
                 }
@@ -77,7 +77,7 @@ Group::Git::Gitosis - Adds reading all repositories you have access to on a gito
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Gitosis version 0.5.3.
+This documentation refers to Group::Git::Gitosis version 0.5.4.
 
 
 =head1 SYNOPSIS
