@@ -13,13 +13,13 @@ use version;
 use Types::Standard qw/Str/;
 use Type::Utils;
 
-our $VERSION = version->new('0.5.3');
+our $VERSION = version->new('0.5.4');
 
 extends 'Group::Git';
 
 has name => (
     is  => 'rw',
-    isa => class_type { class => 'Path::Class::Dir' },
+    isa => class_type { class => 'Path::Tiny' },
 );
 has url => (
     is  => 'rw',
@@ -29,6 +29,30 @@ has git => (
     is  => 'rw',
     isa => Str,
 );
+has mech => (
+    is      => 'rw',
+    lazy    => 1,
+    builder => '_mech',
+);
+
+sub _mech {
+    my ($self) = @_;
+    my $mech;
+
+    if ($self->conf->{cache_dir} && eval { require WWW::Mechanize::Cached }) {
+        $mech = WWW::Mechanize::Cached->new(
+            cache => CHI->new(
+                driver => 'File',
+                root_dir => $self->conf->{cache_dir},
+            ),
+        );
+    }
+    else {
+        $mech  = WWW::Mechanize->new;
+    }
+
+    return $mech;
+}
 
 1;
 
@@ -40,7 +64,7 @@ Group::Git::Repo - Git repository details object.
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Repo version 0.5.3.
+This documentation refers to Group::Git::Repo version 0.5.4.
 
 
 =head1 SYNOPSIS
