@@ -15,9 +15,9 @@ use English qw/ -no_match_vars /;
 use IO::Prompt qw/prompt/;
 use JSON qw/decode_json/;
 use WWW::Mechanize;
-use Path::Class;
+use Path::Tiny;
 
-our $VERSION = version->new('0.5.3');
+our $VERSION = version->new('0.5.4');
 
 extends 'Group::Git';
 
@@ -40,7 +40,7 @@ sub _repos {
 
     my @argv = @ARGV;
     @ARGV = ();
-    my $mech  = WWW::Mechanize->new;
+    my $mech  = $self->mech;
     my $user  = _httpenc( $conf->{username} ? $conf->{username} : prompt( -prompt => 'stash username : ' ) );
     my $pass  = _httpenc( $conf->{password} ? $conf->{password} : prompt( -prompt => 'stash password : ', -echo => '*' ) );
     my $url   = "https://$user:$pass\@$conf->{stash_host}/rest/api/1.0/repos?limit=100&start=";
@@ -56,7 +56,7 @@ sub _repos {
             my $project = $repo->{project}{name};
             my $url     = $repo->{links}{self}[0]{href};
             my %clone   = map {($_->{name} => $_->{href})} @{ $repo->{links}{clone} };
-            my $dir     = $self->recurse ? dir("$project/$repo->{name}") : dir($repo->{name});
+            my $dir     = $self->recurse ? path("$project/$repo->{name}") : path($repo->{name});
 
             $repos{$dir} = Group::Git::Repo->new(
                 name => $dir,
@@ -82,7 +82,7 @@ Group::Git::Stash - Adds reading all repositories you have access to on your loc
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Stash version 0.5.3.
+This documentation refers to Group::Git::Stash version 0.5.4.
 
 =head1 SYNOPSIS
 
